"""Start the vaultgen project."""

from pathlib import Path

CONTENT = """## Context

```context
Here you can define the context of the vault.
```


## Schema

```json
{
    "property": {
        "type": "str" | "int" | "float" | "bool" | "date" | "datetime" | "list" | "link" | ["Option1", "Option2", "Option3"],
        "description": "A property of the note"
        "optional": "True" | "False" // This field is optional if the property is not required.
    }
}
```
"""


def start(vault: Path) -> None:
    """Start the vaultgen project."""
    path = vault.joinpath("config.md")
    path.write_text(CONTENT)
